==> phoenix-starter-rosefinch-0.2.0.2-20241015.063846-1-sources.jar: com/elitesland/cbpl/rosefinch/data/service/RosefinchConfigService.java <==
package com.elitesland.cbpl.rosefinch.data.service;

import com.elitesland.cbpl.rosefinch.client.queue.producer.message.TaskMessage;
import com.elitesland.cbpl.rosefinch.data.vo.param.RosefinchConfigPagingParamVO;
import com.elitesland.cbpl.rosefinch.data.vo.param.RosefinchConfigQueryParamVO;
import com.elitesland.cbpl.rosefinch.data.vo.param.RosefinchConfigSaveParamVO;
import com.elitesland.cbpl.rosefinch.data.vo.resp.RosefinchConfigDetailVO;
import com.elitesland.cbpl.rosefinch.data.vo.resp.RosefinchConfigPagingVO;
import com.elitesland.cbpl.rosefinch.data.vo.resp.RosefinchInstanceDetailVO;
import com.elitesland.cbpl.tool.db.PagingVO;

import java.util.List;

/**
 * @author eric.hao
 * @since 2024/08/06
 */
public interface RosefinchConfigService {

    /**
     * 分页查询
     *
     * @param query 分页参数
     * @return 分页结果
     */
    PagingVO<RosefinchConfigPagingVO> rosefinchConfigPageBy(RosefinchConfigPagingParamVO query);

    /**
     * 不分页查询
     *
     * @param query 查询条件
     * @return 结果列表
     */
    List<RosefinchConfigDetailVO> rosefinchConfigByParam(RosefinchConfigQueryParamVO query);

    /**
     * 明细查询
     *
     * @param id 业务单据ID
     * @return 明细数据
     */
    RosefinchConfigDetailVO rosefinchConfigById(Long id);

    /**
     * 新增或修改
     *
     * @param saveParam 保存参数
     * @return 业务单据ID
     */
    Long save(RosefinchConfigSaveParamVO saveParam);

    /**
     * 启用
     *
     * @param id 业务单据ID
     */
    void active(Long id);

    /**
     * 禁用
     *
     * @param id 业务单据ID
     */
    void inactive(Long id);

    /**
     * 批量物理删除
     *
     * @param ids 业务单据ID
     * @return 删除成功的数量
     */
    void delete(List<Long> ids);

    /**
     * 立即执行一次
     *
     * @param taskCode 任务编码
     * @param payload  业务参数
     */
    void execute(String taskCode, Object payload);

    /**
     * 立即执行一次
     *
     * @param payload 消息报文
     */
    void execute(TaskMessage<?> payload);

    /**
     * 执行函数
     *
     * @param payload 消息报文
     */
    Runnable runAuto(TaskMessage<?> payload);

    /**
     * 立即终止实例
     *
     * @param instance 实例
     * @return 是否终止成功
     */
    boolean stopImmediately(RosefinchInstanceDetailVO instance);

}

==> phoenix-starter-rosefinch-0.2.1.1-20241221.075408-1-sources.jar: com/elitesland/cbpl/rosefinch/data/service/RosefinchConfigService.java <==
package com.elitesland.cbpl.rosefinch.data.service;

import com.elitesland.cbpl.rosefinch.client.queue.producer.message.TaskMessage;
import com.elitesland.cbpl.rosefinch.data.vo.param.RosefinchConfigPagingParamVO;
import com.elitesland.cbpl.rosefinch.data.vo.param.RosefinchConfigQueryParamVO;
import com.elitesland.cbpl.rosefinch.data.vo.param.RosefinchConfigSaveParamVO;
import com.elitesland.cbpl.rosefinch.data.vo.resp.RosefinchConfigDetailVO;
import com.elitesland.cbpl.rosefinch.data.vo.resp.RosefinchConfigPagingVO;
import com.elitesland.cbpl.rosefinch.data.vo.resp.RosefinchInstanceDetailVO;
import com.elitesland.cbpl.tool.db.PagingVO;

import java.util.List;

/**
 * @author eric.hao
 * @since 2024/08/06
 */
public interface RosefinchConfigService {

    /**
     * 分页查询
     *
     * @param query 分页参数
     * @return 分页结果
     */
    PagingVO<RosefinchConfigPagingVO> rosefinchConfigPageBy(RosefinchConfigPagingParamVO query);

    /**
     * 不分页查询
     *
     * @param query 查询条件
     * @return 结果列表
     */
    List<RosefinchConfigDetailVO> rosefinchConfigByParam(RosefinchConfigQueryParamVO query);

    /**
     * 明细查询
     *
     * @param id 业务单据ID
     * @return 明细数据
     */
    RosefinchConfigDetailVO rosefinchConfigById(Long id);

    /**
     * 新增或修改
     *
     * @param saveParam 保存参数
     * @return 业务单据ID
     */
    Long save(RosefinchConfigSaveParamVO saveParam);

    /**
     * 启用
     *
     * @param id 业务单据ID
     */
    void active(Long id);

    /**
     * 禁用
     *
     * @param id 业务单据ID
     */
    void inactive(Long id);

    /**
     * 批量物理删除
     *
     * @param ids 业务单据ID
     * @return 删除成功的数量
     */
    void delete(List<Long> ids);

    /**
     * 立即执行一次
     *
     * @param taskCode 任务编码
     * @param payload  业务参数
     */
    void execute(String taskCode, Object payload);

    /**
     * 立即执行一次
     *
     * @param payload 消息报文
     */
    void execute(TaskMessage payload);

    /**
     * 执行函数
     *
     * @param payload 消息报文
     */
    Runnable runAuto(TaskMessage payload);

    /**
     * 立即终止实例
     *
     * @param instance 实例
     * @return 是否终止成功
     */
    boolean stopImmediately(RosefinchInstanceDetailVO instance);

}
